==> openshift-model-5.7.3-sources.jar: io/fabric8/openshift/api/model/UpdateBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class UpdateBuilder extends io.fabric8.openshift.api.model.UpdateFluentImpl<io.fabric8.openshift.api.model.UpdateBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.Update,io.fabric8.openshift.api.model.UpdateBuilder>{
  public UpdateBuilder() {
    this(false);
  }
  public UpdateBuilder(java.lang.Boolean validationEnabled) {
    this(new Update(), validationEnabled);
  }
  public UpdateBuilder(io.fabric8.openshift.api.model.UpdateFluent<?> fluent) {
    this(fluent, false);
  }
  public UpdateBuilder(io.fabric8.openshift.api.model.UpdateFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new Update(), validationEnabled);
  }
  public UpdateBuilder(io.fabric8.openshift.api.model.UpdateFluent<?> fluent,io.fabric8.openshift.api.model.Update instance) {
    this(fluent, instance, false);
  }
  public UpdateBuilder(io.fabric8.openshift.api.model.UpdateFluent<?> fluent,io.fabric8.openshift.api.model.Update instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withForce(instance.getForce()); 
    fluent.withImage(instance.getImage()); 
    fluent.withVersion(instance.getVersion()); 
    this.validationEnabled = validationEnabled; 
  }
  public UpdateBuilder(io.fabric8.openshift.api.model.Update instance) {
    this(instance,false);
  }
  public UpdateBuilder(io.fabric8.openshift.api.model.Update instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withForce(instance.getForce()); 
    this.withImage(instance.getImage()); 
    this.withVersion(instance.getVersion()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.UpdateFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.Update build() {
    Update buildable = new Update(fluent.getForce(),fluent.getImage(),fluent.getVersion());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    UpdateBuilder that = (UpdateBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/UpdateBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class UpdateBuilder extends io.fabric8.openshift.api.model.UpdateFluentImpl<io.fabric8.openshift.api.model.UpdateBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.Update,io.fabric8.openshift.api.model.UpdateBuilder>{
  public UpdateBuilder() {
    this(false);
  }
  public UpdateBuilder(java.lang.Boolean validationEnabled) {
    this(new Update(), validationEnabled);
  }
  public UpdateBuilder(io.fabric8.openshift.api.model.UpdateFluent<?> fluent) {
    this(fluent, false);
  }
  public UpdateBuilder(io.fabric8.openshift.api.model.UpdateFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new Update(), validationEnabled);
  }
  public UpdateBuilder(io.fabric8.openshift.api.model.UpdateFluent<?> fluent,io.fabric8.openshift.api.model.Update instance) {
    this(fluent, instance, false);
  }
  public UpdateBuilder(io.fabric8.openshift.api.model.UpdateFluent<?> fluent,io.fabric8.openshift.api.model.Update instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withForce(instance.getForce()); 
    fluent.withImage(instance.getImage()); 
    fluent.withVersion(instance.getVersion()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public UpdateBuilder(io.fabric8.openshift.api.model.Update instance) {
    this(instance,false);
  }
  public UpdateBuilder(io.fabric8.openshift.api.model.Update instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withForce(instance.getForce()); 
    this.withImage(instance.getImage()); 
    this.withVersion(instance.getVersion()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.UpdateFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.Update build() {
    Update buildable = new Update(fluent.getForce(),fluent.getImage(),fluent.getVersion());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    UpdateBuilder that = (UpdateBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
